package tse.practico1.mdb;

import java.time.LocalDate;
import java.util.logging.Logger;

import jakarta.ejb.ActivationConfigProperty;
import jakarta.ejb.EJB;
import jakarta.ejb.MessageDriven;
import jakarta.jms.JMSException;
import jakarta.jms.Message;
import jakarta.jms.MessageListener;
import jakarta.jms.TextMessage;
import tse.practico1.Usuario;

/**
 * Message-Driven Bean implementation class for: AltaUsuarioMDB
 */
@MessageDriven(name="AltaUsuarioQueueMDB",
		activationConfig = { 
				@ActivationConfigProperty(propertyName = "destinationLookup", propertyValue = "queue/AltaUsuarioMDBQueue"),
				@ActivationConfigProperty(propertyName = "destinationType", propertyValue = "jakarta.jms.Queue")
		}, 
		messageListenerInterface = MessageListener.class)
public class AltaUsuarioQueueMDB implements MessageListener {
	
	private static final Logger LOGGER = Logger.getLogger(AltaUsuarioQueueMDB.class.toString());
	
	@EJB
	tse.practico1.UsuarioRemote usuarioRemote;

    /**
     * Default constructor. 
     */
    public AltaUsuarioQueueMDB() {
        // TODO Auto-generated constructor stub
    }
	
	/**
     * @see MessageListener#onMessage(Message)
     */
    public void onMessage(Message rcvMessage) {
        TextMessage msg = null;
        try {
        	if (rcvMessage instanceof TextMessage) {
        		msg = (TextMessage) rcvMessage;
        		String text = msg.getText();
        		String[] atributos = text.split("\\|");
        		LOGGER.info("Received Message from queue: " + text);
        		usuarioRemote.altaUsuario(atributos[0], atributos[1], atributos[2]);
        	} else {
        		LOGGER.warning("Message of wrong type: " +  rcvMessage.getClass().getName());
        	}
        } catch (JMSException e) {
        	throw new RuntimeException(e);
        }
    }

}
